
Developer docs
==============
To learn about the inner workings of the ``ricecooker`` library, consult the following docs:

.. toctree::
   :maxdepth: 1

   ids
   ../chefops
   daemonization
   sushops
   design_cli
   corrections
   contributing
   authors
